==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/he.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "אחסון באופן זמני אינו זמין",
    "Storage invalid" : "אחסון לא חוקי",
    "Unknown error" : "שגיאה בלתי ידועה",
    "All files" : "כל הקבצים",
    "Saved" : "נשמר",
    "There was an error saving" : "אירעה שגיאה בשמירה",
    "File could not be found" : "הקובץ לא ניתן לאיתור",
    "Home" : "בית",
    "Close" : "סגירה",
    "Favorites" : "מועדפים",
    "Could not create folder \"{dir}\"" : "לא ניתן ליצור את התיקייה \"{dir}\"",
    "Upload cancelled." : "ההעלאה בוטלה.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "לא ניתן להעלות {filename} כיוון שמדובר בתיקייה או שגודלו 0 בייט",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "לא קיים מספיק מקום פנוי, הקובץ המיועד להעלאה {size1} אבל נשאר {size2} בלבד",
    "Target folder \"{dir}\" does not exist any more" : "תיקיית מטרה \"{dir}\" אינה קיימת יותר",
    "Target folder does not exist any more" : "תיקיית יעד אינה קיימת יותר",
    "Not enough free space" : "אין מספיק זכרון פנוי",
    "Uploading..." : "העלאה...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} מתוך {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "מתבצעת כעת העלאת קבצים. עזיבה של העמוד תבטל את ההעלאה.",
    "Actions" : "פעולות",
    "Download" : "הורדה",
    "Rename" : "שינוי שם",
    "Delete" : "מחיקה",
    "Disconnect storage" : "ניתוק אחסון",
    "Unshare" : "הסר שיתוף",
    "Could not load info for file \"{file}\"" : "לא ניתן היה לטעון מידע \"{file}\"",
    "Files" : "קבצים",
    "Details" : "פרטים",
    "Select" : "בחר",
    "Pending" : "ממתין",
    "Unable to determine date" : "לא ניתן לקבוע תאריך",
    "Invalid path" : "נתיב לא חוקי",
    "This operation is forbidden" : "פעולה זו אסורה",
    "This directory is unavailable, please check the logs or contact the administrator" : "תיקייה זו לא קיימת, יש לבדוק את הלוגים או ליצור קשר עם המנהל",
    "Could not move \"{file}\", target exists" : "לא ניתן להעביר \"{file}\", קובץ מטרה קיים",
    "Could not move \"{file}\"" : "לא ניתן להעביר \"{file}\"",
    "{newName} already exists" : "{newName} כבר קיים",
    "Could not rename \"{fileName}\", it does not exist any more" : "לא ניתן לשנות שם \"{fileName}\", הוא כבר לא קיים יותר",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "השם \"{targetName}\" כבר קיים בתיקייה \"{dir}\". יש לבחור שם אחר.",
    "Could not rename \"{fileName}\"" : "לא ניתן לשנות את השם \"{fileName}\"",
    "Could not create file \"{file}\"" : "לא ניתן ליצור את הקובץ \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "לא ניתן ליצור את הקובץ \"{file}\" כיוון שהוא כבר קיים",
    "Could not create folder \"{dir}\" because it already exists" : "לא ניתן ליצור את התיקייה \"{dir}\" כיוון שהיא כבר קיימת",
    "Error deleting file \"{fileName}\"." : "שגיאה בזמן מחיקת קובץ \"{fileName}\".",
    "No entries in this folder match {filter}" : "אין כניסות לתיקייה נבחרת זו {filter}",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "_%n folder_::_%n folders_" : ["%n תיקייה","%n תיקיות"],
    "_%n file_::_%n files_" : ["%n קובץ","%n קבצים"],
    "{dirs} and {files}" : "{dirs} וכן {files}",
    "_including %n hidden_::_including %n hidden_" : ["מכיל %n מוסתר","מכיל %n מוסתרים"],
    "You don’t have permission to upload or create files here" : "אין לך הרשאות להעלות או ליצור קבצים כאן",
    "_Uploading %n file_::_Uploading %n files_" : ["מעלה %n קובץ","מעלה %n קבצים"],
    "New" : "חדש",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "\"{name}\" has a forbidden file type/extension." : "ל- \"{name}\" יש סוג/סיומת קובץ אסור..",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "האחסון של {owner} מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Your storage is full, files can not be updated or synced anymore!" : "האחסון שלך מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "האחסון של {owner} כמעט מלא ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "שטח האחסון שלך כמעט מלא ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["מתאים ל- '{filter}'","מתאים ל- '{filter}'"],
    "Path" : "נתיב",
    "_%n byte_::_%n bytes_" : ["%n בייט","%n בייטים"],
    "Favorited" : "מועדף",
    "Favorite" : "מועדף",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "קישור פרטי: רק אנשים שיש להם גישה לקובץ/ספריה יכולים להשתמש בו. ניתן להשתמש בו כקישור קבע לעצמך או להפנות אחרים לקבצים השייכים לשיתוף",
    "Folder" : "תיקייה",
    "New folder" : "תיקייה חדשה",
    "{newname} already exists" : "{newname} כבר קיים",
    "Upload" : "העלאה",
    "An error occurred while trying to update the tags" : "שגיאה אירעה בזמן עדכון התגיות",
    "A new file or folder has been <strong>created</strong>" : "קובץ או תיקייה חדשים <strong>נוצרו<strong/>",
    "A file or folder has been <strong>changed</strong>" : "קובץ או תיקייה <strong>שונו<strong/>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "הגבלת הודעות על יצירת או שינוי <strong>הקבצים המועדפים</strong> שלך <em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "קובץ או תיקייה <strong>נמחקו<strong/>",
    "A file or folder has been <strong>restored</strong>" : "קובץ או תיקייה <strong>שוחזר</strong>",
    "You created %1$s" : "יצרת %1$s",
    "%2$s created %1$s" : "%2$s נוצרו %1$s",
    "%1$s was created in a public folder" : "%1$s נוצר בתיקייה ציבורית",
    "You changed %1$s" : "שינית %1$s",
    "%2$s changed %1$s" : "%2$s שונו %1$s",
    "You deleted %1$s" : "מחקת %1$s",
    "%2$s deleted %1$s" : "%2$s נמחקו %1$s",
    "You restored %1$s" : "שחזרת %1$s",
    "%2$s restored %1$s" : "%2$s שוחזרו %1$s",
    "Changed by %2$s" : "שונו על ידי %2$s",
    "Deleted by %2$s" : "נמחקו על ידי %2$s",
    "Restored by %2$s" : "שוחזרו על ידי %2$s",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "File handling" : "טיפול בקבצים",
    "Maximum upload size" : "גודל העלאה מקסימלי",
    "max. possible: " : "המרבי האפשרי: ",
    "Save" : "שמירה",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "בשימוש ב- PHP-FPM זה יכול להמשך 5 דקות לשינויים לחול.",
    "Missing permissions to edit from here." : "חסרות הרשאות לעריכה מכאן.",
    "Settings" : "הגדרות",
    "Show hidden files" : "הצגת קבצים נסתרים",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "ניתן להשתמש בכתובת זו כדי <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">להכנס לקבצים שלך באמצעות WebDAV</a>",
    "No files in here" : "אין כאן קבצים",
    "Upload some content or sync with your devices!" : "יש להעלות קצת תוכן או לסנכרן עם ההתקנים שלך!",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Select all" : "לבחור הכול",
    "Upload too large" : "העלאה גדולה מידי",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "הקבצים שניסית להעלות חרגו מהגודל המקסימלי להעלאת קבצים על שרת זה.",
    "No favorites" : "אין מועדפים",
    "Files and folders you mark as favorite will show up here" : "קבצים ותיקיות שסומנו על ידך כמועדפים יוצגו כאן",
    "Text file" : "קובץ טקסט",
    "New text file.txt" : "קובץ טקסט חדש.txt",
    "Upload timeout for file \"{file}\"" : "פסק זמן בזמן העלאה של קובץ \"{file}\"",
    "Processing files..." : "מעבד קבצים...",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "הגבלת התראות על יצירה או שינוי של <strong>קבצים מועדפים</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "אין לך הרשאות לגשת לקובץ/תיקייה - יש ליצור קשר עם הבעלים לשיתופם איתך.",
    "Error when assembling chunks, status code {status}" : "שגיאה בזמן בניית פיסות מידע למשלוח, קוד מצב {status}",
    "Unknown user" : "משתמש לא ידוע"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/he.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "אחסון באופן זמני אינו זמין",
    "Storage invalid" : "אחסון לא חוקי",
    "Unknown error" : "שגיאה בלתי ידועה",
    "All files" : "כל הקבצים",
    "File could not be found" : "הקובץ לא ניתן לאיתור",
    "Home" : "בית",
    "Close" : "סגירה",
    "Favorites" : "מועדפים",
    "Upload timeout for file \"{file}\"" : "פסק זמן בזמן העלאה של קובץ \"{file}\"",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "שגיאה לא ידועה \"{error}\" בזמן העלאת קובץ \"{file}\"",
    "Could not create folder \"{dir}\"" : "לא ניתן ליצור את התיקייה \"{dir}\"",
    "Upload cancelled." : "ההעלאה בוטלה.",
    "The file {file} already exists" : "הקובץ {file} כבר קיים",
    "Processing files..." : "מעבד קבצים...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "לא ניתן להעלות {filename} כיוון שמדובר בתיקייה או שגודלו 0 בייט",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "לא קיים מספיק מקום פנוי, הקובץ המיועד להעלאה {size1} אבל נשאר {size2} בלבד",
    "Target folder \"{dir}\" does not exist any more" : "תיקיית מטרה \"{dir}\" אינה קיימת יותר",
    "Target folder does not exist any more" : "תיקיית יעד אינה קיימת יותר",
    "The file {file} is currently locked, please try again later" : "הקובץ {file} כרגע נעול, אפשר לנסות שוב מאוחר יותר",
    "Not enough free space" : "אין מספיק זכרון פנוי",
    "Uploading..." : "העלאה...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} מתוך {totalSize} ({bitrate})",
    "Error when assembling chunks, status code {status}" : "שגיאה בזמן בניית פיסות מידע למשלוח, קוד מצב {status}",
    "File upload is in progress. Leaving the page now will cancel the upload." : "מתבצעת כעת העלאת קבצים. עזיבה של העמוד תבטל את ההעלאה.",
    "Actions" : "פעולות",
    "Download" : "הורדה",
    "Rename" : "שינוי שם",
    "Delete" : "מחיקה",
    "Disconnect storage" : "ניתוק אחסון",
    "Unshare" : "הסר שיתוף",
    "Could not load info for file \"{file}\"" : "לא ניתן היה לטעון מידע \"{file}\"",
    "Files" : "קבצים",
    "Details" : "פרטים",
    "Select" : "בחר",
    "Pending" : "ממתין",
    "Unable to determine date" : "לא ניתן לקבוע תאריך",
    "Invalid path" : "נתיב לא חוקי",
    "This operation is forbidden" : "פעולה זו אסורה",
    "This directory is unavailable, please check the logs or contact the administrator" : "תיקייה זו לא קיימת, יש לבדוק את הלוגים או ליצור קשר עם המנהל",
    "group" : "קבוצה",
    "Remote share" : "שיתוף חיצוני",
    "via" : "באמצעות",
    "Could not move \"{file}\", target exists" : "לא ניתן להעביר \"{file}\", קובץ מטרה קיים",
    "Could not move \"{file}\" because either the file or the target are locked." : "לא ניתן להעביר את הקובץ \"{file}\" כיוון שאו שהקובץ או תיקיית המטרה נעולים.",
    "Could not move \"{file}\": {message}" : "לא ניתן להעביר את \"{file}\": {message}",
    "Could not move \"{file}\"" : "לא ניתן להעביר \"{file}\"",
    "{newName} already exists" : "{newName} כבר קיים",
    "Could not rename \"{fileName}\", it does not exist any more" : "לא ניתן לשנות שם \"{fileName}\", הוא כבר לא קיים יותר",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "השם \"{targetName}\" כבר קיים בתיקייה \"{dir}\". יש לבחור שם אחר.",
    "The file \"{fileName}\" is locked and can not be renamed." : "הקובץ \"{fileName}\" נעול ולא ניתן לשנות את שמו.",
    "Could not rename \"{fileName}\"" : "לא ניתן לשנות את השם \"{fileName}\"",
    "Could not create file \"{file}\"" : "לא ניתן ליצור את הקובץ \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "לא ניתן ליצור את הקובץ \"{file}\" כיוון שהוא כבר קיים",
    "Could not create folder \"{dir}\" because it already exists" : "לא ניתן ליצור את התיקייה \"{dir}\" כיוון שהיא כבר קיימת",
    "The file \"{fileName}\" is locked and cannot be deleted." : "הקובץ \"{fileName}\" נעול ולא ניתן למחוק אותו.",
    "Error deleting file \"{fileName}\"." : "שגיאה בזמן מחיקת קובץ \"{fileName}\".",
    "No entries in this folder match {filter}" : "אין כניסות לתיקייה נבחרת זו {filter}",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "_%n folder_::_%n folders_" : ["%n תיקייה","%n תיקיות","%n תיקיות","%n תיקיות"],
    "_%n file_::_%n files_" : ["%n קובץ","%n קבצים","%n קבצים","%n קבצים"],
    "{dirs} and {files}" : "{dirs} וכן {files}",
    "_including %n hidden_::_including %n hidden_" : ["מכיל %n מוסתר","מכיל %n מוסתרים","מכיל %n מוסתרים","מכיל %n מוסתרים"],
    "You don’t have permission to upload or create files here" : "אין לך הרשאות להעלות או ליצור קבצים כאן",
    "_Uploading %n file_::_Uploading %n files_" : ["מעלה %n קובץ","מעלה %n קבצים","מעלה %n קבצים","מעלה %n קבצים"],
    "New" : "חדש",
    "Unknown user" : "משתמש לא ידוע",
    "Lock status" : "מצב נעילה",
    "This resource is locked. Click to see more details." : "המשאב נעול. יש ללחוץ לקבלת פרטים נוספים.",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "File name cannot contain \"/\"." : "שם קובץ אינו יכול להכיל \"/\".",
    "\"{name}\" has a forbidden file type/extension." : "ל- \"{name}\" יש סוג/סיומת קובץ אסור..",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "האחסון של {owner} מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Your storage is full, files can not be updated or synced anymore!" : "האחסון שלך מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "האחסון של {owner} כמעט מלא ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "שטח האחסון שלך כמעט מלא ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["מתאים ל- '{filter}'","מתאים ל- '{filter}'","מתאים ל- '{filter}'","מתאים ל- '{filter}'"],
    "{owner} has locked this resource via {path}" : "{owner} נעל את המשאב באמצעות {path}",
    "Could not unlock, please contact the lock owner {owner}" : "לא ניתן להסיר את הנעילה, יש לפנות למי שנעל {owner}",
    "Unlock failed with status {status}" : "ביטול הנעילה נכשל עם סטטוס {status}",
    "Locks" : "נעילות",
    "Resource is not locked" : "המשאב אינו נעול",
    "Path" : "נתיב",
    "_%n byte_::_%n bytes_" : ["%n בייט","%n בייטים","%n בייטים","%n בייטים"],
    "Favorited" : "מועדף",
    "Favorite" : "מועדף",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "קישור פרטי: רק אנשים שיש להם גישה לקובץ/ספריה יכולים להשתמש בו. ניתן להשתמש בו כקישור קבע לעצמך או להפנות אחרים לקבצים השייכים לשיתוף",
    "Folder" : "תיקייה",
    "New folder" : "תיקייה חדשה",
    "{newname} already exists" : "{newname} כבר קיים",
    "Upload" : "העלאה",
    "An error occurred while trying to update the tags" : "שגיאה אירעה בזמן עדכון התגיות",
    "A new file or folder has been <strong>created</strong>" : "קובץ או תיקייה חדשים <strong>נוצרו<strong/>",
    "A file or folder has been <strong>changed</strong>" : "קובץ או תיקייה <strong>שונו<strong/>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "הגבלת הודעות על יצירת או שינוי <strong>הקבצים המועדפים</strong> שלך <em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "קובץ או תיקייה <strong>נמחקו<strong/>",
    "A file or folder has been <strong>restored</strong>" : "קובץ או תיקייה <strong>שוחזר</strong>",
    "You created %1$s" : "יצרת %1$s",
    "%2$s created %1$s" : "%2$s נוצרו %1$s",
    "%1$s was created in a public folder" : "%1$s נוצר בתיקייה ציבורית",
    "You changed %1$s" : "שינית %1$s",
    "%2$s changed %1$s" : "%2$s שונו %1$s",
    "You deleted %1$s" : "מחקת %1$s",
    "%2$s deleted %1$s" : "%2$s נמחקו %1$s",
    "You restored %1$s" : "שחזרת %1$s",
    "%2$s restored %1$s" : "%2$s שוחזרו %1$s",
    "Changed by %2$s" : "שונו על ידי %2$s",
    "Deleted by %2$s" : "נמחקו על ידי %2$s",
    "Restored by %2$s" : "שוחזרו על ידי %2$s",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "אין לך הרשאות לגשת לקובץ/תיקייה - יש ליצור קשר עם הבעלים לשיתופם איתך.",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "Settings" : "הגדרות",
    "Show hidden files" : "הצגת קבצים נסתרים",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "ניתן להשתמש בכתובת זו כדי <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">להכנס לקבצים שלך באמצעות WebDAV</a>",
    "No files in here" : "אין כאן קבצים",
    "Upload some content or sync with your devices!" : "יש להעלות קצת תוכן או לסנכרן עם ההתקנים שלך!",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Select all" : "לבחור הכול",
    "Upload too large" : "העלאה גדולה מידי",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "הקבצים שניסית להעלות חרגו מהגודל המקסימלי להעלאת קבצים על שרת זה.",
    "No favorites" : "אין מועדפים",
    "Files and folders you mark as favorite will show up here" : "קבצים ותיקיות שסומנו על ידך כמועדפים יוצגו כאן",
    "Text file" : "קובץ טקסט",
    "New text file.txt" : "קובץ טקסט חדש.txt"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
